==> qmmp_0.5.2.orig.tar.gz: qmmp-0.5.2/src/plugins/Visual/analyzer/translations/analyzer_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="51"/>
        <source>Qmmp Analyzer</source>
        <translation>Qmmp frekvenční analyzátor</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Analyzer Plugin Settings</source>
        <translation>Nastavení modulu frekvenčního analyzátoru</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="25"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Show peaks</source>
        <translation>Zobrazovat špičky</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Analyzer falloff:</source>
        <translation>Pokles analyzátoru:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Slowest</source>
        <translation>Nejpomalejší</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="60"/>
        <location filename="../settingsdialog.ui" line="102"/>
        <source>Slow</source>
        <translation>Pomalý</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="65"/>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Medium</source>
        <translation>Střední</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <location filename="../settingsdialog.ui" line="112"/>
        <source>Fast</source>
        <translation>Rychlý</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Fastest</source>
        <translation>Nejrychlejší</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="83"/>
        <source>Peaks falloff:</source>
        <translation>Pokles špiček:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="125"/>
        <source>Refresh rate:</source>
        <translation>Obnovovací frekvence:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>50 FPS</source>
        <translation>50 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="144"/>
        <source>25 FPS</source>
        <translation>25 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="149"/>
        <source>10 FPS</source>
        <translation>10 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="154"/>
        <source>5 FPS</source>
        <translation>5 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Colors</source>
        <translation>Barvy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="177"/>
        <source>Peaks:</source>
        <translation>Špičky:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #1:</source>
        <translation>Analyzátor #1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Background:</source>
        <translation>Pozadí:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="255"/>
        <source>Analyzer #2:</source>
        <translation>Analyzátor #2:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="294"/>
        <source>Analyzer #3:</source>
        <translation>Analyzátor #3:</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>Modul frekvenčního analyzátoru</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>O modulu frekvenčního analyzátoru</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Modul frekvenčního analyzátoru pro Qmmp</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/Visual/analyzer/translations/analyzer_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="56"/>
        <source>Qmmp Analyzer</source>
        <translation>Frekvenční analyzátor Qmmp</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="77"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>ColorWidget</name>
    <message>
        <location filename="../colorwidget.cpp" line="37"/>
        <source>Select Color</source>
        <translation>Vyberte barvu</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Analyzer Plugin Settings</source>
        <translation>Nastavení modulu frekvenčního analyzátoru</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="26"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Show peaks</source>
        <translation>Zobrazovat špičky</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Analyzer falloff:</source>
        <translation>Pokles analyzátoru:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="56"/>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Slowest</source>
        <translation>Nejpomalejší</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Slow</source>
        <translation>Pomalý</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <location filename="../settingsdialog.ui" line="108"/>
        <source>Medium</source>
        <translation>Střední</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <location filename="../settingsdialog.ui" line="113"/>
        <source>Fast</source>
        <translation>Rychlý</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <location filename="../settingsdialog.ui" line="118"/>
        <source>Fastest</source>
        <translation>Nejrychlejší</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Peaks falloff:</source>
        <translation>Pokles špiček:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <source>Refresh rate:</source>
        <translation>Obnovovací frekvence:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="140"/>
        <source>50 FPS</source>
        <translation>50 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="145"/>
        <source>25 FPS</source>
        <translation>25 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="150"/>
        <source>10 FPS</source>
        <translation>10 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="155"/>
        <source>5 FPS</source>
        <translation>5 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="163"/>
        <source>Cells size:</source>
        <translation>Velikost polí:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="223"/>
        <source>Colors</source>
        <translation>Barvy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Peaks:</source>
        <translation>Špičky:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="261"/>
        <source>Analyzer #1:</source>
        <translation>Analyzátor #1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="293"/>
        <source>Background:</source>
        <translation>Pozadí:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="325"/>
        <source>Analyzer #2:</source>
        <translation>Analyzátor #2:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="370"/>
        <source>Analyzer #3:</source>
        <translation>Analyzátor #3:</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>Modul frekvenčního analyzátoru</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>O modulu frekvenčního analyzátoru</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Modul frekvenčního analyzátoru pro Qmmp</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
